#!/bin/sh
# chkconfig: 345 87 12
# description: milter-spamc
#

# REQUIRE: syslogd
# BEFORE:  mail
# KEYWORD: FreeBSD NetBSD

prefix="/usr/local"
exec_prefix="${prefix}"
PROGRAM="${exec_prefix}/sbin/milter-spamc"
OPTIONS="unix:/var/lib/milter-spamc/socket"
REQUIRED_DIR="/var/lib/milter-spamc"

FG_RED='\033[1;31m'
FG_GREEN='\033[1;32m'
FG_WHITE='\033[0;37m'
FG_BLACK='\033[0;30m'
FG_NORMAL=${FG_WHITE}

##########################################################################
#	Nothing to be configured below this point.
##########################################################################

# Program present?
if [ ! -f "$PROGRAM" ]; then
	echo "$PROGRAM" not found.
	exit 0;
fi

if [ ! -d $REQUIRED_DIR ]; then
	echo $REQUIRED_DIR not found.
	exit 0;
fi

os=`uname -s`

getpid()
{
	case $os in
	Linux*)
		NAME=`basename $1`
ps acxj | grep "$NAME" | sed -n -e '/ 1 /{
s/^ *[^ ]*  *\([0-9][0-9]*\).*/\1/
p
}'
		;;
	SunOS)
ps -ef | grep "$1" | sed -n -e '/ 1 /{
s/^ *[^ ]*  *\([0-9][0-9]*\).*/\1/
p
}'
		;;
	*BSD*)
		NAME=`basename $1`
ps -acxj | grep "$NAME" | sed -n -e '/ 1 /{
s/^ *[^ ]*  *\([0-9][0-9]*\).*/\1/
p
}'
		;;
	esac
}

start()
{
	NAME=`basename "$PROGRAM"`
        printf "Starting %s" $NAME

	pid=`getpid "$PROGRAM"`
	if [ X"$pid" != X ]; then
		printf '\r\033[71C['${FG_RED}'FAILED'${FG_NORMAL}']\n'
		return
	fi

	# Make sure the old socket has been removed, especially for FreeBSD.
	rm -f ${REQUIRED_DIR}/socket

	# Start the program in the background from a sub-shell
	# so that process will appear in the ps output immediately.
	sh -c "$PROGRAM $OPTIONS &"

	pid=`getpid "$PROGRAM"`
	if [ X"$pid" = X ]; then
		printf '\r\033[71C['${FG_RED}'FAILED'${FG_NORMAL}']\n'
		return
	fi

	printf '\r\033[71C['${FG_GREEN}'  OK  '${FG_NORMAL}']\n'
}

stop()
{
	NAME=`basename "$PROGRAM"`
        printf "Stopping %s" $NAME

	pid=`getpid "$PROGRAM"`
	if [ X"$pid" != X ]; then
		# The libmilter documentation specifies that only
		# uncatchable signals can kill the milter, so no
		# point in trying a clean shutdown. HUP, TERM, and
		# INT are slow, in that they wait for connections
		# to complete or for the next request by Sendmail.
		kill -KILL $pid

		sleep 2
		pid=`getpid "$PROGRAM"`
		if [ X"$pid" != X ]; then
			printf '\r\033[71C['${FG_RED}'FAILED'${FG_NORMAL}']\n'
			return
		fi
	fi

	printf '\r\033[71C['${FG_GREEN}'  OK  '${FG_NORMAL}']\n'
}

case "$1" in
restart)
	stop
	start
	;;
start)
	start
	;;
stop)
	stop
	;;
status)
	pid=`getpid "$PROGRAM"`
	if [ X"$pid" != X ]; then
		printf '\r\033[72C['${FG_GREEN}${pid}${FG_NORMAL}']\n'
	else
		printf '\r\033[70C['${FG_RED}'STOPPED'${FG_NORMAL}']\n'
	fi
	;;
*)
	printf 'Usage: %s {start|stop|restart|status}\n' $0
	exit 1
esac

exit $?

